@@ -1,6 +1,8 @@
 #coding: utf-8
 from flask import current_app, g, request, abort
 from flask_login import current_user
+from itsdangerous import exc
+from jinja2 import TemplateSyntaxError
 from jinja2.ext import Extension
 from jinja2.nodes import List, CallBlock
 from esentity.models import Page
@@ -686,7 +688,7 @@ class CasinosExtension(Extension):
                 'is_searchable': True,
                 'is_redirect': False,
                 'country': current_user.country_full,
-                'tags': 'casino',
+                'services': 'casino',
                 'provider_tags': tags,
                 '_source': True, 
                 '_count': count,
@@ -702,7 +704,6 @@ class CasinosExtension(Extension):
             found=found, 
             has_filters=has_filters, 
             count=count,
-
             # id=id, 
             # tags=tags,
         )
@@ -1405,6 +1406,7 @@ class PagesExtension(Extension):
             **kwargs,
             _source = [
                 "title", 
+                "alt_title",
                 "path", 
             ], 
             _count=count,
@@ -1436,7 +1438,7 @@ class PagesListExtension(Extension):
     def _render(self, args, caller=None):
         logger.info(f'pages_list Args IN: {args}')
 
-        default = [20, 4]
+        default = [20, 4, 'pages_list', [], {'tags': 'Promo'}, None]
         _ca = len(default)
         args = args[:_ca] + default[len(args):] + args[_ca:]
 
@@ -1444,17 +1446,22 @@ class PagesListExtension(Extension):
 
         count = int(args[0])
         cols = int(args[1])
+        template = args[2]
+        tags = args[3]
+        exclude = args[4]
+        css = args[5]
 
         pages, found = Page.get(
             is_active=True,
             is_searchable=True,
             is_redirect=False,
-            category=['page', 'category'],
-            tags='Blog',
-            _exclude_params={'tags': 'Promo'},
+            category=['page', 'collection'],
+            tags=tags or ['Blog'],
+            _exclude_params=exclude,
             _sort=[{'publishedon': {'order': 'desc'}}],
             _source = [
                 "title", 
+                "alt_title",
                 "path", 
                 "cover",
                 "publishedon"
@@ -1462,10 +1469,11 @@ class PagesListExtension(Extension):
             _count=count,
         )
 
-        t = current_app.jinja_env.get_template('_ext-pages-list.html')
+        t = current_app.jinja_env.get_template(f'_ext-{template}.html')
         s = t.render(
             pages=pages, 
-            cols=cols
+            cols=cols,
+            css=css,
         )
         return s
 
@@ -1480,25 +1488,118 @@ class PagesListExtension(Extension):
         return CallBlock(self.call_method("_render", args=[List(args)]), [], [], []).set_lineno(lineno)          
 
 
-class PromoPagesExtension(Extension):
-    tags = set(['promo_pages'])
+# class PromoPagesExtension(Extension):
+#     tags = set(['promo_pages'])
+
+#     def __init__(self, environment):
+#         super(PromoPagesExtension, self).__init__(environment)
+
+#     def _render(self, caller):
+#         t = current_app.jinja_env.get_template('_ext-promo_pages.html')
+#         s = t.render()
+#         return s
+
+#     def parse(self, parser):
+#         lineno = next(parser.stream).lineno
+#         return CallBlock(self.call_method("_render", []), [], [], '').set_lineno(lineno)
+
+
+# class TocExtension(Extension):
+#     tags = set(['toc'])
+
+#     def __init__(self, environment):
+#         super(TocExtension, self).__init__(environment)
+
+#     def _render(self, caller):
+#         rv = caller()
+
+#         def parse_item(s):
+#             v, k = s.split('#')
+#             return {'anchor': f'#{k}', 'title': v}
+
+#         items = [parse_item(item) for item in rv.strip().split(';')]
+
+#         t = current_app.jinja_env.get_template('_ext-toc.html')
+#         s = t.render(items=items)
+
+#         return s
+
+#     def parse(self, parser):
+#         lineno = next(parser.stream).lineno
+
+#         body = parser.parse_statements(['name:endtoc'], drop_needle=True)
+#         args = []
+
+#         return CallBlock(self.call_method("_render", args), [], [], body).set_lineno(lineno)
+
+
+class UIExtension(Extension):
+    tags = set(['ui'])
 
     def __init__(self, environment):
-        super(PromoPagesExtension, self).__init__(environment)
+        super(UIExtension, self).__init__(environment)
+
+    def _render(self, args, caller):
+        logger.info(f'ui Args IN: {args}')
+
+        default = ['features', False]
+        _ca = len(default)
+        args = args[:_ca] + default[len(args):] + args[_ca:]
+
+        logger.info('ui Args OUT: {0}'.format(args))
+
+        template = args[0]
+        parse_content = bool(args[1])
+
+        rv = caller().strip()
+        items = []
+
+        if parse_content:
+            def parse_item(s):
+                k, v = s.split(':')
+                return {'key': k, 'value': v}
+            items = [parse_item(item) for item in rv.split('|')]
+
+        t = current_app.jinja_env.get_template(f'_ext-ui_{template}.html')
+        # html.unescape(rv)
+        s = t.render(items=items, rv=rv, args=args)
+
+        return s
+
+    def parse(self, parser):
+        tag = parser.stream.__next__()
+
+        args = []
+        try:
+            while parser.stream.current.type != 'block_end':
+                args.append(parser.parse_expression())
+                parser.stream.skip_if('comma')
+        except TemplateSyntaxError:
+            pass
+
+        body = parser.parse_statements(['name:endui'], drop_needle=True)
+
+        callback = self.call_method('_render', args=[List(args)])
+        return CallBlock(callback, [], [], body).set_lineno(tag.lineno)
+
+
+class ComplaintsStatsExtension(Extension):
+    tags = set(['complaints_stats'])
+
+    def __init__(self, environment):
+        super(ComplaintsStatsExtension, self).__init__(environment)
 
     def _render(self, caller):
-        t = current_app.jinja_env.get_template('_ext-promo_pages.html')
-        pages = [
-            {'path': '/blog/best-bitcoin-casinos/', 'icon': 'vpns', 'title': 'Best Bitcoin <br/>Casinos'},
-            {'path': '/blog/best-ethereum-casinos/', 'icon': 'vpns', 'title': 'Best Ethereum <br/>Casinos'},
-            {'path': '/blog/best-casino-games/', 'icon': 'vpns', 'title': 'Best Casino <br/>Games'},
-            {'path': '/blog/casino-of-the-month/', 'icon': 'vpns', 'title': 'Casino <br/>of the Month'},
-            {'path': '/blog/best-vpns/', 'icon': 'vpns', 'title': 'Best <br/>VPN\'s'},
-            {'path': '/blog/the-uk-casinos/', 'icon': 'vpns', 'title': 'Best Casino <br/>in the UK'},
-        ]
-        s = t.render(pages=pages)
+        stats = {}
+        try:
+            stats = loads(current_app.redis.get('gs:complaints_stats').decode('utf-8'))
+        except Exception:
+            pass
+
+        t = current_app.jinja_env.get_template('_ext-complaint_stats.html')
+        s = t.render(stats=stats)
         return s
 
     def parse(self, parser):
         lineno = next(parser.stream).lineno
-        return CallBlock(self.call_method("_render", []), [], [], '').set_lineno(lineno)
+        return CallBlock(self.call_method("_render", []), [], [], '').set_lineno(lineno)
\ No newline at end of file
