@@ -341,7 +341,8 @@ class Page(ElasticEntity):
         'category': str,
         'locale': str,
         'locale_available': list, # for lang version
-        'hreflang': str,
+        'hreflang': str, # current lang for page
+        'hreflang_tags': list,
         'source_chain': list,
         'api_source': str,
         'alias': str,
@@ -379,6 +380,7 @@ class Page(ElasticEntity):
         'is_commented': bool,
         'comments': list,
         'is_amp': bool,
+        'params': list,
 
         'tags': list, # for page: news, category
         'cover': str, # for page: collection, provider, page
@@ -475,6 +477,9 @@ class Page(ElasticEntity):
         'rank_alexa': int,
         'applications': list,
         'applications_review': str,
+        'trustpilot_url': str,
+        'trustpilot_rate_value': float,
+        'trustpilot_reviews_value': int,
 
         'collection': list,
         'collection_category': str,
@@ -539,7 +544,7 @@ class Page(ElasticEntity):
     
     @classmethod
     def get_options(cls):
-        _cnt = 500
+        _cnt = 1000
 
         aggs = {
             "tags": {
@@ -751,10 +756,11 @@ class Page(ElasticEntity):
                 'is_jackpot:bool',
                 'licences_info.number:str',
             ],
-            'collection_sort': ['Func_1', 'Func_2', 'Rate', 'Rank', 'Views', 'Activity', 'Alexa', 'Adding', 'AZ', 'Launched', 'RTP', 'MaxWin', 'Jackpot', 'Min.Deposit'],
+            'collection_sort': ['Func_1', 'Func_2', 'Rate', 'Rank', 'Views', 'Activity', 'Alexa', 'Trustpilot Rate', 'Trustpilot Reviews', 'Adding', 'AZ', 'Launched', 'RTP', 'MaxWin', 'Jackpot', 'Min.Deposit'],
             'collection_sort_direction': ['Desc', 'Asc'],
             'collection_paging': ['FirstPage', 'Paging'],
-            'hreflangs': current_app.config['AVAILABLE_LOCALE'],
+            'hreflangs': [],
+            'params_presets': {},
         }
         
         return opts
@@ -1088,6 +1094,8 @@ class Guest(AnonymousUserMixin):
 
     @property
     def location_iso(self):
+        if current_app.config.get('STATIC_LOCATION'):
+            return current_app.config.get('STATIC_LOCATION')
         if self.user_agent.is_bot:
             return 'gb'
         else:
@@ -1100,10 +1108,14 @@ class Guest(AnonymousUserMixin):
 
     @property
     def country(self):
+        if current_app.config.get('STATIC_LOCATION'):
+            return self.location_iso
         return request.cookies.get('iso', self.location_iso)
 
     @property
     def country_full(self):
+        if current_app.config.get('STATIC_LOCATION'):
+            return self.location
         return unquote(request.cookies.get('country', self.location))
 
     @property
@@ -1803,9 +1815,7 @@ class ActivityFeedbackModel(BaseModel):
 
 
 class ActivityComplaintModel(BaseModel):
-    name: str = ...
-    country: str = ...
-    casino_selected: dict = ...
+    casino: str = ...
     amount: str = ...
     currency: str = ...
     message: str = ...
